@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
-#include <config.h>
+#include "config.h"
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <string.h>
