@@ -37,7 +37,7 @@
  * we warned you and we're not liable for any head injuries.
  */
 
-#include <config.h>
+#include "config.h"
 #include <string.h>
 
 #include "gtktreemodelsort.h"
@@ -201,11 +201,11 @@ static void         gtk_tree_model_sort_set_sort_func         (GtkTreeSortable
 							       gint                    sort_column_id,
 							       GtkTreeIterCompareFunc  func,
 							       gpointer                data,
-							       GtkDestroyNotify        destroy);
+							       GDestroyNotify          destroy);
 static void         gtk_tree_model_sort_set_default_sort_func (GtkTreeSortable        *sortable,
 							       GtkTreeIterCompareFunc  func,
 							       gpointer                data,
-							       GtkDestroyNotify        destroy);
+							       GDestroyNotify          destroy);
 static gboolean     gtk_tree_model_sort_has_default_sort_func (GtkTreeSortable     *sortable);
 
 /* Private functions (sort funcs, level handling and other utils) */
@@ -1356,7 +1356,7 @@ gtk_tree_model_sort_set_sort_func (GtkTreeSortable        *sortable,
 				   gint                    sort_column_id,
 				   GtkTreeIterCompareFunc  func,
 				   gpointer                data,
-				   GtkDestroyNotify        destroy)
+				   GDestroyNotify          destroy)
 {
   GtkTreeModelSort *tree_model_sort = (GtkTreeModelSort *) sortable;
 
@@ -1372,13 +1372,13 @@ static void
 gtk_tree_model_sort_set_default_sort_func (GtkTreeSortable        *sortable,
 					   GtkTreeIterCompareFunc  func,
 					   gpointer                data,
-					   GtkDestroyNotify        destroy)
+					   GDestroyNotify          destroy)
 {
   GtkTreeModelSort *tree_model_sort = (GtkTreeModelSort *)sortable;
 
   if (tree_model_sort->default_sort_destroy)
     {
-      GtkDestroyNotify d = tree_model_sort->default_sort_destroy;
+      GDestroyNotify d = tree_model_sort->default_sort_destroy;
 
       tree_model_sort->default_sort_destroy = NULL;
       d (tree_model_sort->default_sort_data);
@@ -1917,23 +1917,23 @@ gtk_tree_model_sort_set_model (GtkTreeModelSort *tree_model_sort,
       gint i, n_columns;
 
       tree_model_sort->changed_id =
-        g_signal_connect (child_model, "row_changed",
+        g_signal_connect (child_model, "row-changed",
                           G_CALLBACK (gtk_tree_model_sort_row_changed),
                           tree_model_sort);
       tree_model_sort->inserted_id =
-        g_signal_connect (child_model, "row_inserted",
+        g_signal_connect (child_model, "row-inserted",
                           G_CALLBACK (gtk_tree_model_sort_row_inserted),
                           tree_model_sort);
       tree_model_sort->has_child_toggled_id =
-        g_signal_connect (child_model, "row_has_child_toggled",
+        g_signal_connect (child_model, "row-has-child-toggled",
                           G_CALLBACK (gtk_tree_model_sort_row_has_child_toggled),
                           tree_model_sort);
       tree_model_sort->deleted_id =
-        g_signal_connect (child_model, "row_deleted",
+        g_signal_connect (child_model, "row-deleted",
                           G_CALLBACK (gtk_tree_model_sort_row_deleted),
                           tree_model_sort);
       tree_model_sort->reordered_id =
-	g_signal_connect (child_model, "rows_reordered",
+	g_signal_connect (child_model, "rows-reordered",
 			  G_CALLBACK (gtk_tree_model_sort_rows_reordered),
 			  tree_model_sort);
 
@@ -2398,7 +2398,7 @@ gtk_tree_model_sort_reset_default_sort_func (GtkTreeModelSort *tree_model_sort)
 
   if (tree_model_sort->default_sort_destroy)
     {
-      GtkDestroyNotify d = tree_model_sort->default_sort_destroy;
+      GDestroyNotify d = tree_model_sort->default_sort_destroy;
 
       tree_model_sort->default_sort_destroy = NULL;
       d (tree_model_sort->default_sort_data);
